==> aliyun-python-sdk-companyreg-1.2.1.tar.gz: aliyun-python-sdk-companyreg-1.2.1/aliyunsdkcompanyreg/request/v20201022/SavePayrollSettingRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class SavePayrollSettingRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'SavePayrollSetting')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_BizId(self):
		return self.get_query_params().get('BizId')

	def set_BizId(self,BizId):
		self.add_query_param('BizId',BizId)

	def get_PayrollAutoGrantRule(self):
		return self.get_query_params().get('PayrollAutoGrantRule')

	def set_PayrollAutoGrantRule(self,PayrollAutoGrantRule):
		self.add_query_param('PayrollAutoGrantRule',PayrollAutoGrantRule)

	def get_PayrollGrantMode(self):
		return self.get_query_params().get('PayrollGrantMode')

	def set_PayrollGrantMode(self,PayrollGrantMode):
		self.add_query_param('PayrollGrantMode',PayrollGrantMode)

==> aliyun-python-sdk-companyreg-2.2.2.tar.gz: aliyun-python-sdk-companyreg-2.2.2/aliyunsdkcompanyreg/request/v20201022/SavePayrollSettingRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class SavePayrollSettingRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2020-10-22', 'SavePayrollSetting')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_BizId(self): # String
		return self.get_query_params().get('BizId')

	def set_BizId(self, BizId):  # String
		self.add_query_param('BizId', BizId)
	def get_PayrollAutoGrantRule(self): # String
		return self.get_query_params().get('PayrollAutoGrantRule')

	def set_PayrollAutoGrantRule(self, PayrollAutoGrantRule):  # String
		self.add_query_param('PayrollAutoGrantRule', PayrollAutoGrantRule)
	def get_PayrollGrantMode(self): # String
		return self.get_query_params().get('PayrollGrantMode')

	def set_PayrollGrantMode(self, PayrollGrantMode):  # String
		self.add_query_param('PayrollGrantMode', PayrollGrantMode)
